@@ -1,6 +1,6 @@
 import sys
 
-from PyQt5.QtCore import Qt, QRect, QSize, QModelIndex
+from PyQt5.QtCore import Qt, QRect, QSize, QModelIndex, QEasingCurve
 from PyQt5.QtGui import QPainter, QBrush, QColor, QLinearGradient, QPalette
 from PyQt5.QtWidgets import QFrame, QVBoxLayout, QScrollArea, QStackedLayout
 
@@ -186,12 +186,7 @@ class RightPanel(QFrame):
 
     def show_background_image(self, pixmap):
         self._pixmap = pixmap
-        if pixmap is None:
-            self.table_container.meta_widget.setMinimumHeight(0)
-        else:
-            height = (self._app.height() - self.bottom_panel.height() -
-                      self.table_container.toolbar.height()) // 2
-            self.table_container.meta_widget.setMinimumHeight(height)
+        self._adjust_meta_widget_height()
         self.update()
 
     def paintEvent(self, e):
@@ -220,6 +215,7 @@ class RightPanel(QFrame):
         scrolled = self.scrollarea.verticalScrollBar().value()
         max_scroll_height = draw_height - self.bottom_panel.height()
 
+        # Do not draw the pixmap when it is not shown.
         if scrolled >= max_scroll_height:
             painter.save()
             painter.setBrush(self.palette().brush(QPalette.Window))
@@ -230,6 +226,15 @@ class RightPanel(QFrame):
         if self._pixmap is not None:
             self._draw_pixmap(painter, draw_width, draw_height, scrolled)
             self._draw_pixmap_overlay(painter, draw_width, draw_height, scrolled)
+            curve = QEasingCurve(QEasingCurve.OutCubic)
+            alpha_ratio = min(scrolled / max_scroll_height, 1)
+            alpha = 250 * curve.valueForProgress(alpha_ratio)
+            painter.save()
+            color = self.palette().color(QPalette.Window)
+            color.setAlpha(alpha)
+            painter.setBrush(color)
+            painter.drawRect(self.bottom_panel.rect())
+            painter.restore()
         else:
             # draw gradient for widgets(bottom panel + meta_widget + ...) above table
             self._draw_overlay(painter, draw_width, draw_height, scrolled)
@@ -312,4 +317,23 @@ class RightPanel(QFrame):
 
     def sizeHint(self):
         size = super().sizeHint()
-        return QSize(760, size.height())
+        return QSize(660, size.height())
+
+    def resizeEvent(self, e):
+        super().resizeEvent(e)
+        if self._pixmap is not None and e.oldSize().width() != e.size().width():
+            self._adjust_meta_widget_height()
+
+    def _adjust_meta_widget_height(self):
+        # HACK: adjust height of table_container's meta_widget to
+        # adapt to background image.
+        if self._pixmap is None:
+            self.table_container.meta_widget.setMinimumHeight(0)
+        else:
+            height = (self._background_image_height_hint() -
+                      self.bottom_panel.height() -
+                      self.table_container.toolbar.height())
+            self.table_container.meta_widget.setMinimumHeight(height)
+
+    def _background_image_height_hint(self):
+        return self.width() * 5 // 9
